* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Jira Service Management Integration](https://help.sap.com/docs/leanix/ea/jira-service-management-integration)
  * Relation Mapping Between Jira Service Management an…
